MIN_LENGTH = 1
MAX_LENGTH = 400

IDENTIFIER_REGEX_CONDITION = r"^[A-Za-z0-9\.\-:_,=\/@]+$"
MSMQ_NAME_REGEX_CONDITION = r"^[A-Za-z0-9_\.]+$"
NAME_REGEX_CONDITION = r"^[A-Za-z0-9/\-_:,\s@\.]+$"


ORG = "ORG"
APPLICATION = "APP"
PROJECT = "PRJ"
TYPE = "TYPE"
NAMESPACE = "NS"

# SERVICE_CONFIG_ID FE
SERVICE_CONFIG_ID_SSO_FE = "sso_fe"

# SERVICE_CONFIG_ID API
SERVICE_CONFIG_ID_UTILS_API = "utils_api"
SERVICE_CONFIG_ID_SSO_API = "sso_api"
SERVICE_CONFIG_ID_GATEWAY_API = "gateway_api"
SERVICE_CONFIG_ID_CERTS_API = "certs_api"
SERVICE_CONFIG_ID_PERMS_API = "perms_api"
SERVICE_CONFIG_ID_REMIND_API = "remind_api"
SERVICE_CONFIG_ID_FILE_API = "file_api"
SERVICE_CONFIG_ID_ACCOUNTS_API = "accounts_api"
SERVICE_CONFIG_ID_BIND_API = "bind_api"
SERVICE_CONFIG_ID_ESP_GATEWAY_API = "esp_gateway_api"
SERVICE_CONFIG_ID_ESP_POSTMARK_API = "esp_postmark_api"


# COMMON ACTIONS
INBOUND_SIGNAL_CLEAR_OUTPOST = "INBOUND_SIGNAL_CLEAR_OUTPOST"
